==> hsqldb_2.5.1.orig.tar.xz: hsqldb-2.5.1/hsqldb/src/org/hsqldb/lib/FilteredIterator.java <==
/* Copyright (c) 2001-2020, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.lib;

import java.util.NoSuchElementException;

/**
 *
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 2.5.1
 * @since 2.5.1
 */
public class FilteredIterator<E> implements Iterator {

    final Iterator<E> it;
    final Filter<E> filter;

    E nextValue;

    public FilteredIterator (Iterator<E> iterator, Filter<E> filter ) {
        this.it = iterator;
        this.filter = filter;

        moveNext();
    }

    public boolean hasNext() {

        return nextValue != null;
    }

    public E next() throws NoSuchElementException {
        E returnValue = nextValue;

        moveNext();
        return returnValue;
    }

    private void moveNext() {
        while(it.hasNext()) {
            E unfilteredValue = it.next();

            if (filter.test(unfilteredValue)) {
                nextValue = unfilteredValue;
                return;
            }
        }

        nextValue = null;
    }

    public int nextInt() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public long nextLong() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public void remove() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public void setValue(Object value) {
        throw new NoSuchElementException("Iterator");
    }

    public interface Filter<E> {
        boolean test(E object);
    }

}

==> hsqldb_2.6.1.orig.tar.xz: hsqldb-2.6.1/hsqldb/src/org/hsqldb/lib/FilteredIterator.java <==
/* Copyright (c) 2001-2021, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.lib;

import java.util.NoSuchElementException;

/**
 * An iterator with an added filter.
 *
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 2.6.0
 * @since 2.5.1
 */
public class FilteredIterator<E> implements Iterator<E> {

    private final Iterator<E> it;
    private final Filter<E>   filter;
    private       E           nextValue;

    public FilteredIterator (Iterator<E> iterator, Filter<E> filter ) {
        this.it = iterator;
        this.filter = filter;

        moveNext();
    }

    public boolean hasNext() {

        return nextValue != null;
    }

    public E next() throws NoSuchElementException {
        E returnValue = nextValue;

        moveNext();
        return returnValue;
    }

    private void moveNext() {
        while(it.hasNext()) {
            E unfilteredValue = it.next();

            if (filter.test(unfilteredValue)) {
                nextValue = unfilteredValue;
                return;
            }
        }

        nextValue = null;
    }

    public int nextInt() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public long nextLong() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public void remove() throws NoSuchElementException {
        throw new NoSuchElementException("Iterator");
    }

    public interface Filter<E> {
        boolean test(E object);
    }

}
